{% if conversation_facts %}
  {% for participant, facts in conversation_facts.items() %}
- name: "facts_{{ loop.index }}"
  truncation_priority: 3
  content: |
    {% if participant == "narrator" %}
      {% for fact in facts %}
        {{ settings.start_token }}narrator: {{ escape_special_characters(fact.value) }}{{ settings.eom }}
      {% endfor %}
    {% else %}
      {{ settings.start_token }}{{ escape_special_characters(participant) }}: I am:
        {% for fact in facts %}
          - {{ escape_special_characters(fact.category) }}: {{ escape_special_characters(fact.value) }}
        {% endfor %}
      {{ settings.eom }}
      {% set settings.start_token = settings.bom %}
    {% endif %}
  {% endfor %}
{% endif %}
