- name: "reply_prompt"
  content: |
    {{ settings.start_token }}{{ escape_special_characters(reply_prompt) }}

{% if "heather_voice" in model_id %}
- name: "special audio token"
  content: |
    {{ settings.audio_mode_token }}
{% endif %}
