"""C.AI specific constants for the Hermes engine."""

NARRATOR_NAME = "narrator"
DEFAULT_USERNAME = "user"
TRUNCATION_STEPS_CHOICES = [250, 500, 750, 1000, 1250, 1500]
PRETRUNCATION_TOKENS_PER_MESSAGE = 10
BOD = "<|beginningofdialog|>"
BOM = "<|beginningofmessage|>"
EOM = "<|endofmessage|>"
