{# Description: Default production template. #}
{% set settings = namespace() %}

{% from 'macros/global_settings.yml.j2' import init_settings with context%}
{{ init_settings(settings) }}

{% include 'sections/validate_inputs.yml.j2' %}

{# WARNING: This name `bod_ts` must be first part in the template! #}
{% include 'sections/bod_timestamp.yml.j2' %}

{% if scene_info %}
{% include 'sections/scene_definition_raw.yml.j2' %}
{% else %}
{% include 'sections/character_definition_raw.yml.j2' %}
{% endif %}

{% include 'sections/persona_definition_raw.yml.j2' %}

{% include 'sections/audio_mode_instruction.yml.j2' %}

{% include 'sections/facts.yml.j2' %}

{% include 'sections/chat_context_message_pins_raw.yml.j2' %}

{% include 'sections/chat_context_messages_raw.yml.j2' %}

{% include 'sections/reply_prompt.yml.j2' %}
