{% for msg in get_scene_definition(character, username, scene_info) %}
- name: "scene_definition_message_{{ loop.index }}"
  content: |
    {{ settings.start_token }}{{  maybe_inject_narrator(escape_special_characters(msg)) }}{{ settings.eom }}
    {%- set settings.start_token = settings.bom -%}
{% endfor %}
