- name: "message_character_original_greeting"
  content: |
    {{ settings.start_token }}{{ escape_special_characters(character_greeting_prompt) }}

- name: "message_rephrase_greeting_prompt"
  content: |
    {{ settings.start_token }}{{ escape_special_characters(dynamic_greeting_prompt) }}
