{% if persona_definition %}
  {% if not template_params or not template_params.dont_use_persona_definition %}
- name: "persona"
  content: |
    {{ settings.start_token }}{{ canonicalize_user_name(username) }}: {{ escape_special_characters(persona_definition) }}{{ settings.eom }}
  {% set settings.start_token = settings.bom %}
  {% endif %}
{% endif %}
